package com.ruoyi.web.controller.place;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.place.TdPlace;
import com.ruoyi.web.controller.manager.TdPlaceManager;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * packageName com.ruoyi.web.controller.place
 *
 * @author wangxy
 * @version JDK 8
 * @className TdPlaceController
 * @date 2024/8/13
 * @description 涉密场所等级
 */
@Controller
@RequestMapping("/system/place")
public class TdPlaceController  extends BaseController {


    private String prefix = "system/place";

    @Resource
    private TdPlaceManager placeManager;


    @RequiresPermissions("system:place:view")
    @GetMapping()
    public String tdmeeting() {
        return prefix + "/place";
    }

    /**
     * 场所列表
     */
    @RequiresPermissions("system:place:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TdPlace tdPlace) {
        startPage();
        List<TdPlace> tdPlaces = placeManager.selectTdPlaceList(tdPlace);
        return getDataTable(tdPlaces);
    }


    /**
     * 新增场所
     */
    @GetMapping("/add")
    public String add() {
        return prefix + "/add";
    }

    /**
     * 新增场所
     */
    @RequiresPermissions("system:place:add")
    @Log(title = "涉密场所", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TdPlace tdPlace) {
        return toAjax(placeManager.saveOrUpdate(tdPlace));
    }

    /**
     * 修改场所
     */
    @RequiresPermissions("system:place:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap) {
        TdPlace tdPlace = placeManager.selectTdPlace(id);
        mmap.put("tdPlace", tdPlace);
        return prefix + "/edit";
    }

    /**
     * 修改会议
     */
    @RequiresPermissions("system:place:edit")
    @Log(title = "涉密场所", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TdPlace tdPlace) {
        return toAjax(placeManager.saveOrUpdate(tdPlace));
    }

    /**
     * 详情场所
     */
    @RequiresPermissions("system:place:detail")
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap) {
        TdPlace tdPlace = placeManager.selectTdPlace(id);
        mmap.put("tdPlace", tdPlace);
        return prefix + "/detail";
    }

    /**
     * 删除场所
     */
    @RequiresPermissions("system:place:remove")
    @Log(title = "涉密场所", businessType = BusinessType.DELETE)
    @PostMapping("/remove")
    @ResponseBody
    public AjaxResult remove(String ids) {
        return toAjax(placeManager.deletedPlaceByids(ids));
    }

    /**
     *
     *  查询所有场所
     * @return com.ruoyi.common.core.domain.AjaxResult
     */
    @PostMapping("/getList")
    @ResponseBody
    public AjaxResult getList() {
        return AjaxResult.success(placeManager.selectList());
    }



}
