package com.ruoyi.web.controller.system.count;

import java.util.List;

import cn.hutool.core.convert.Convert;
import com.ruoyi.system.domain.userbook.dto.UserBookDTO;
import com.ruoyi.system.domain.userexam.dto.request.UserExamReqDTO;
import com.ruoyi.system.domain.userexam.dto.response.UserExamExportDTO;
import com.ruoyi.system.domain.userexam.dto.response.UserExamRespDTO;
import com.ruoyi.web.controller.manager.UserExamManager;
import io.swagger.annotations.ApiOperation;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TdExamnum;
import com.ruoyi.system.service.ITdExamnumService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

/**
 * 考试结果Controller
 *
 * @author ruoyi
 * @date 2024-04-10
 */
@Controller
@RequestMapping("/system/examnum")
public class TdExamnumController extends BaseController {
    private String prefix = "system/examnum";

    @Autowired
    private ITdExamnumService tdExamnumService;

    @Resource
    private UserExamManager userExamManager;


    @RequiresPermissions("system:examnum:countExam")
    @GetMapping()
    public String countExam() {
        return prefix + "/countExam";
    }


    @GetMapping("/examnum/{examId}")
    public String examnum(@PathVariable("examId") String examId, ModelMap mmap) {
        mmap.put("examId",examId);
        return prefix + "/examnum";
    }

    /**
     * 查询考试结果列表
     */
    @RequiresPermissions("system:examnum:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(UserExamReqDTO reqDTO) {
        startPage();
        List<UserExamRespDTO> list = userExamManager.selectExamList(reqDTO);
        return getDataTable(list);
    }

    /**
     * 导出考试结果列表
     */
    @RequiresPermissions("system:examnum:export")
    @Log(title = "考试详情", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(UserExamReqDTO reqDTO) {
        List<UserExamRespDTO> list = userExamManager.selectExamList(reqDTO);
        List<UserExamExportDTO> list1 = Convert.toList(UserExamExportDTO.class, list);
        ExcelUtil<UserExamExportDTO> util = new ExcelUtil<UserExamExportDTO>(UserExamExportDTO.class);
        return util.exportExcel(list1, "考试数据");
    }


    @ApiOperation("查找考试总数")
    @PostMapping("/countList")
    @ResponseBody
    public AjaxResult countList() {
        return AjaxResult.success(userExamManager.selectCountList());
    }

    @ApiOperation("最新考试列表")
    @PostMapping("/countExamList")
    @ResponseBody
    public AjaxResult countExamList() {
        return AjaxResult.success(userExamManager.selectCountExam());
    }


}
